# - Config to retrieve all components of the gz-physics7 package
#
# This should only be invoked by gz-physics7-config.cmake.
#
# To retrieve this meta-package, use:
# find_package(gz-physics7 COMPONENTS all)
#
# This creates the target gz-physics7::all which will link to all known
# components of gz-physics7, including the core library.
#
# This also creates the variable gz-physics7_ALL_LIBRARIES
#
################################################################################

cmake_minimum_required(VERSION 3.10.2 FATAL_ERROR)

if(gz-physics7_ALL_CONFIG_INCLUDED)
  return()
endif()
set(gz-physics7_ALL_CONFIG_INCLUDED TRUE)

if(NOT gz-physics7-all_FIND_QUIETLY)
  message(STATUS "Looking for all libraries of gz-physics7 -- found version 7.1.0")
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was gz-all-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/x86_64-linux-gnu/cmake/gz-physics7-all" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)

# Find the core library
find_dependency(gz-physics7 7.1.0 EXACT)

# Find the component libraries
find_dependency(gz-physics7-sdf 7.1.0 EXACT)
find_dependency(gz-physics7-heightmap 7.1.0 EXACT)
find_dependency(gz-physics7-mesh 7.1.0 EXACT)
find_dependency(gz-physics7-dartsim 7.1.0 EXACT)
find_dependency(gz-physics7-dartsim-plugin 7.1.0 EXACT)
find_dependency(gz-physics7-tpelib 7.1.0 EXACT)
find_dependency(gz-physics7-tpe 7.1.0 EXACT)
find_dependency(gz-physics7-tpe-plugin 7.1.0 EXACT)
find_dependency(gz-physics7-bullet 7.1.0 EXACT)
find_dependency(gz-physics7-bullet-plugin 7.1.0 EXACT)
find_dependency(gz-physics7-bullet-featherstone 7.1.0 EXACT)
find_dependency(gz-physics7-bullet-featherstone-plugin 7.1.0 EXACT)

if(NOT TARGET gz-physics7::gz-physics7-all)
  include("${CMAKE_CURRENT_LIST_DIR}/gz-physics7-all-targets.cmake")

  add_library(gz-physics7::all INTERFACE IMPORTED)
  set_target_properties(gz-physics7::all PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-physics7::gz-physics7-all")

endif()

# Create the "requested" target if it does not already exist
if(NOT TARGET gz-physics7::requested)
  add_library(gz-physics7::requested INTERFACE IMPORTED)
endif()

# Link the "all" target to the "requested" target
get_target_property(gz_requested_components gz-physics7::requested INTERFACE_LINK_LIBRARIES)
if(NOT gz_requested_components)
  set_target_properties(gz-physics7::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-physics7::gz-physics7-all")
else()
  set_target_properties(gz-physics7::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${gz_requested_components};gz-physics7::gz-physics7-all")
endif()

set(gz-physics7_ALL_LIBRARIES gz-physics7::gz-physics7-all)
